package com.muyu.enterprise.remote;

import com.muyu.enterprise.remote.factory.RemoteMessageValueServiceFactory;
import com.muyu.common.core.constant.ServiceNameConstants;
import com.muyu.common.core.domain.Result;
import com.muyu.enterprise.domain.resp.car.MessageValueListResp;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;

/**
 * 报文数据服务
 * @Author：李庆帅
 * @Package：com.muyu.analysis.parsing.feign
 * @Project：cloud-server
 * @name：RemoteServiceClient
 * @Date：2024/9/28 20:38
 */
@FeignClient(
        path = "/messageValue",
        contextId = "remoteMessageValueService",
        value = ServiceNameConstants.ENTERPRISE_SERVICE,
        fallbackFactory= RemoteMessageValueServiceFactory.class
)
public interface RemoteMessageValueService {

    /**
     * 根据报文模版id查询报文数据
     * @param templateId 请求对象
     * @return 返回结果
     */
    @GetMapping("/findByTemplateId/{templateId}")
//    @Operation(summary = "根据报文模版id查询报文数据", description = "根据报文模版id查询报文数据")
    public Result<List<MessageValueListResp>> findByTemplateId(@PathVariable("templateId") Long templateId);

}
