package com.muyu.enterprise.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.enterprise.domain.CarMessageType;
import com.muyu.enterprise.service.CarMessageTypeService;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 报文类型--控制层
 * @ClassName CarMessageTypeController
 * @Description 报文类型 Controller 层
 * @author  MingWei.Zong
 * @Date 2024/9/28 16:52
 */
@RestController
@RequestMapping("/carMessageType")
/** 构造必备注解  只有用 final 修饰 才会被构造注入   */
@RequiredArgsConstructor //制动构造注入 默认无参 Lombook包下
@Tag(name = "报文类型" ,description = "报文类型")
public class CarMessageTypeController extends BaseController {

    private final CarMessageTypeService sysCarMessageTypeService;

    /**
     * 查询报文类型
     * @return
     */
    @PostMapping("messageTypeList")
    public Result messageTypeList(){
        startPage();
        List<CarMessageType> list = sysCarMessageTypeService.list();
        return Result.success(list);
    }

    /**
     * 添加报文类型
     * @param carMessageType
     * @return
     */
    @PostMapping("inserMessageType")
    public Result inserMessageType(@RequestBody CarMessageType carMessageType){
        /** 报文类型 */
        if(StringUtils.isEmpty(carMessageType.getMessageType())){
            return Result.error("报文类型不能为空");
        }
        /** 报文 */
        if(StringUtils.isEmpty(carMessageType.getMessageName())){
            return Result.error("报文不能为空");
        }
        /** 报文编码 */
        if(StringUtils.isEmpty(carMessageType.getMessageCode())){
            return Result.error("报文编码不能为空");
        }
        /** 报文字段类型 */
        if(StringUtils.isEmpty(carMessageType.getMessageClass())){
            return Result.error("报文字段类型不能为空");
        }
        sysCarMessageTypeService.save(carMessageType);
        return Result.success("添加成功");
    }

    /**
     * 修改报文类型
     * @param carMessageType
     * @return
     */
    @PostMapping("updateMessageType")
    public Result updateMessageType(@RequestBody CarMessageType carMessageType){
        /** 报文类型 */
        if(StringUtils.isEmpty(carMessageType.getMessageType())){
            return Result.error("报文类型不能为空");
        }
        /** 报文 */
        if(StringUtils.isEmpty(carMessageType.getMessageName())){
            return Result.error("报文不能为空");
        }
        /** 报文编码 */
        if(StringUtils.isEmpty(carMessageType.getMessageCode())){
            return Result.error("报文编码不能为空");
        }
        /** 报文字段类型 */
        if(StringUtils.isEmpty(carMessageType.getMessageClass())){
            return Result.error("报文字段类型不能为空");
        }
        sysCarMessageTypeService.updateById(carMessageType);
        return Result.success("修改成功");
    }



}
