package com.muyu.enterprise.controller;

import com.muyu.enterprise.domain.CarTemplate;
import com.muyu.enterprise.service.CarTemplateService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
/**
 * 报文模版--控制层
 * @ClassName CarTemplateController
 * @Description 报文模版 Controller 层
 * @author  MingWei.Zong
 * @Date 2024/9/28 16:52
 */
@RestController
@RequestMapping("/carTemplate") // 报文模版
/** 构造必备注解  只有用 final 修饰 才会被构造注入   */
@RequiredArgsConstructor //制动构造注入 默认无参 Lombook包下
@Tag(name = "模版模块",description = "报文模版模块")
public class CarTemplateController extends BaseController {

    private final CarTemplateService sysCarTemplateService;

    /**
     * 查询所有模版信息
     * @return
     */
    @PostMapping("selectTemplateShow")
    public List<CarTemplate> selectTemplateShow(){
        startPage();
        return sysCarTemplateService.selectTemplateShow();
    }
    /**
     * 通过id查询模版信息
     * @return
     */
    @PostMapping("selectTemplateByTemplateId")
    public CarTemplate selectTemplateByTemplateId(@RequestParam("templateId") Long templateId){
        return sysCarTemplateService.selectTemplateByTemplateId(templateId);
    }

   /**
     * 添加模版信息
     * @return carMessage
     */
    @PostMapping("insertTemplate")
    public Result insertTemplate(@RequestBody CarTemplate carTemplate){
        sysCarTemplateService.save(carTemplate);
        return Result.success("添加成功");
    }
    /**
     * 修改模版信息
     * @return carMessage
     */
    @PostMapping("updataTemplate")
    public Result updataTemplate(@RequestBody CarTemplate carTemplate){
        sysCarTemplateService.updateById(carTemplate);
        return Result.success("修改成功");
    }
    /**
     * 删除模版信息
     * @return carMessage
     */
    @PostMapping("deleteTemplate")
    public Result deleteTemplate(@RequestParam("ids") List<Long> ids){
        sysCarTemplateService.removeBatchByIds(ids);
        return Result.success("删除成功");
    }


}
