package com.muyu.enterprise.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.enterprise.domain.resp.WarnStrategy;
import com.muyu.enterprise.service.IWarnStrategyService;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.List;

/**
 * 预警策略Controller
 *
 * @author muyu
 * @date 2024-09-20
 */
@RestController
@RequestMapping("/strategy")
@Tag(name = "故障策略",description = "故障策略对应车辆类型用来客户选择")
public class WarnStrategyController extends BaseController
{
    @Resource
    private IWarnStrategyService warnStrategyService;

    /**
     * 查询预警策略列表
     */
    @RequiresPermissions("warn:strategy:list")
    @GetMapping("/list")
    public Result<TableDataInfo<com.muyu.enterprise.domain.WarnStrategy>> list(com.muyu.enterprise.domain.WarnStrategy warnStrategy)
    {
        startPage();
        List<com.muyu.enterprise.domain.WarnStrategy> list = warnStrategyService.selectWarnStrategyList(warnStrategy);
        return getDataTable(list);
    }

    /**
     * 导出预警策略列表
     */
    @RequiresPermissions("warn:strategy:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, com.muyu.enterprise.domain.WarnStrategy warnStrategy)
    {
        List<com.muyu.enterprise.domain.WarnStrategy> list = warnStrategyService.selectWarnStrategyList(warnStrategy);
        ExcelUtil<com.muyu.enterprise.domain.WarnStrategy> util = new ExcelUtil<com.muyu.enterprise.domain.WarnStrategy>(com.muyu.enterprise.domain.WarnStrategy.class);
        util.exportExcel(response, list, "预警策略数据");
    }

    /**
     * 获取预警策略详细信息
     */
    @RequiresPermissions("warn:strategy:query")
    @GetMapping(value = "/{id}")
    public Result<List<com.muyu.enterprise.domain.WarnStrategy>> getInfo(@PathVariable("id") Long id)
    {
        return success(warnStrategyService.selectWarnStrategyById(id));
    }

    /**
     * 新增预警策略
     */
    @RequiresPermissions("warn:strategy:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody com.muyu.enterprise.domain.WarnStrategy warnStrategy)
    {
        if (warnStrategyService.checkIdUnique(warnStrategy)) {
            return error("新增 预警策略 '" + warnStrategy + "'失败，预警策略已存在");
        }
        return toAjax(warnStrategyService.save(warnStrategy));
    }

    /**
     * 修改预警策略
     */
    @RequiresPermissions("warn:strategy:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody com.muyu.enterprise.domain.WarnStrategy warnStrategy)
    {
        if (!warnStrategyService.checkIdUnique(warnStrategy)) {
            return error("修改 预警策略 '" + warnStrategy + "'失败，预警策略不存在");
        }
        return toAjax(warnStrategyService.updateById(warnStrategy));
    }

    /**
     * 删除预警策略
     */
    @RequiresPermissions("warn:strategy:remove")
	@DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids)
    {
        warnStrategyService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }

    /**
     * 双表联查
     * @param warnStrategy
     * @return
     */
    @PostMapping("/strategyRuleList")
    public Result<List<WarnStrategy>> StrategyRuleList(@RequestBody com.muyu.enterprise.domain.WarnStrategy warnStrategy){
        List<WarnStrategy> list = warnStrategyService.strategyList(warnStrategy);
        return Result.success(list);
    }
}
