package com.muyu.enterprise.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.enterprise.cache.CarManageCacheService;
import com.muyu.enterprise.controller.CarCompanyController;
import com.muyu.enterprise.domain.CarCompany;
import com.muyu.enterprise.domain.CarConfig;
import com.muyu.enterprise.domain.CarManage;
import com.muyu.enterprise.domain.dto.CarDTO;
import com.muyu.enterprise.domain.vo.CarVO;
import com.muyu.enterprise.mapper.CarManageMapper;
import com.muyu.enterprise.service.CarCompanyService;
import com.muyu.enterprise.service.CarConfigService;
import com.muyu.enterprise.service.CarManageService;
import com.muyu.common.redis.service.RedisService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 车辆管理--业务实现层
 * @ClassName CarManageServiceImpl
 * @Description 车辆管理 ServiceImpl 层
 * @author  MingWei.Zong
 * @Date 2024/9/28 16:52
 */
@Service
public class CarManageServiceImpl extends ServiceImpl<CarManageMapper, CarManage>
        implements CarManageService {

    @Autowired
    private CarCompanyService carCompanyService;
    @Autowired
    private CarConfigService carConfigService;
    @Autowired
    private CarManageCacheService carManageCacheService;
    @Autowired
    private CarManageMapper carManageMapper;

    /**
     * 车辆列表2
     * @param carDTO
     * @return
     */
    @Override
    public List<CarVO> carListShow2(CarDTO carDTO) {
                // 获取 企业
        CarManage carManage = BeanUtil.copyProperties(carDTO, CarManage.class);
        List<CarManage> list = lambdaQuery()
                .eq(carManage.getCarVin() != null && carManage.getCarVin() != "", CarManage::getCarVin, carManage.getCarVin())
                .eq(carManage.getCarModel() != null && carManage.getCarModel() != "", CarManage::getCarModel, carManage.getCarModel())
                .eq(carManage.getCarBrand() != null && carManage.getCarBrand() != "", CarManage::getCarBrand, carManage.getCarBrand())
                .eq(carManage.getCarStatus() != null && carManage.getCarStatus() > 0, CarManage::getCarStatus, carManage.getCarStatus())
                .eq(carManage.getEnterpriseId() != null && carManage.getEnterpriseId() > 0, CarManage::getEnterpriseId, carManage.getEnterpriseId())
                .list();
//        List<CarManage> list = list();

        // 把 查询出来的车辆数据 copy 到 CarVO
        List<CarVO> carVOS = BeanUtil.copyToList(list, CarVO.class);
        // 遍历赋值
        carVOS.forEach(carVO -> {
            // 查询出对象,用于赋值
            CarConfig carConfig = carConfigService.selectByConfigId(carVO.getConfigId());
            carVO.setConfigName(carConfig.getConfigName());
            carVO.setEnergyType(carConfig.getEnergyType());
            carVO.setGearType(carConfig.getGearType());
            // 查询出对象,用于赋值
            CarCompany carCompany = carCompanyService.selectCompanyByCompanyId(carVO.getEnterpriseId());
            carVO.setCompanyName(carCompany.getCompanyName());
            // 存到 redis
            carManageCacheService.put(carVO.getCarVin(),new CarManage());
        });


        return carVOS;
    }
    @Override
    public List<CarVO> CarListShow(CarDTO carDTO) {
        // 获取 企业
        CarManage carManage = BeanUtil.copyProperties(carDTO, CarManage.class);
        return carManageMapper.selectJoinList(CarVO.class, new MPJLambdaWrapper<CarManage>()
                .selectAll(CarManage.class) // 查询所有车辆表
                .select(CarCompany::getCompanyName)
                .select(CarConfig::getConfigName)
                .select(CarConfig::getGearType)
                .select(CarConfig::getEnergyType)
                .leftJoin(CarConfig.class, CarConfig::getConfigId, CarManage::getConfigId)
                .leftJoin(CarCompany.class, CarCompany::getEnterpriseId, CarManage::getEnterpriseId)
                .eq(carManage.getCarVin() != null && carManage.getCarVin() != "", CarManage::getCarVin, carManage.getCarVin())
                .eq(carManage.getCarModel() != null && carManage.getCarModel() != "", CarManage::getCarModel, carManage.getCarModel())
                .eq(carManage.getCarBrand() != null && carManage.getCarBrand() != "", CarManage::getCarBrand, carManage.getCarBrand())
                .eq(carManage.getCarStatus() != null && carManage.getCarStatus() > 0, CarManage::getCarStatus, carManage.getCarStatus())
                .eq(carManage.getEnterpriseId() != null && carManage.getEnterpriseId() > 0, CarManage::getEnterpriseId, carManage.getEnterpriseId())
        );


    }

    @Override
    public void insertCar(CarManage carVO) {
        save(carVO);
        // 存到缓存中去
        carManageCacheService.put(carVO.getCarVin(),new CarManage());
    }


}
