package com.muyu.event.process.consumer;

import com.muyu.enterprise.cache.CarFaultCacheService;
import com.muyu.enterprise.cache.CarManageCacheService;
import com.muyu.enterprise.cache.CarWarnCacheService;
import com.muyu.enterprise.cache.ElectronicFenceCacheService;
import com.muyu.event.process.constant.CacheHandlerConstants;
import com.muyu.event.process.util.CacheUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.ExchangeTypes;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.HashMap;

/**
 * @Author: zi run
 * @Date 2024/10/6 10:01
 * @Description 车辆上线消费者
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class GoOnlineConsumer {

    /**
     * 存储通用类型数据缓存工具
     */
    private final CacheUtil<Object> cacheUtil;

    /**
     * 车辆管理缓存服务
     */
    private final CarManageCacheService carManageCacheService;

    /**
     * 车辆故障缓存服务
     */
    private final CarFaultCacheService carFaultCacheService;

    /**
     * 车辆电子围栏缓存服务
     */
    private final ElectronicFenceCacheService electronicFenceCacheService;

    /**
     * 车辆预警缓存服务
     */
    private final CarWarnCacheService carWarnCacheService;

    /**
     * 处理车辆上线事件
     *
     * @param vin 车辆的识别码，根据识别码从缓存中存入对应的数据
     */
    @RabbitListener(
            bindings = @QueueBinding(
                    value = @Queue(value = "GO_ONLINE", durable = "true"),
                    exchange = @Exchange(value = "ONLINE_EXCHANGE", type = ExchangeTypes.FANOUT)
            )
    )
    public void online(String vin) {
        log.info("车辆vin码：{}，该车辆已上线", vin);
        cacheUtil.put(vin, new HashMap<String, Object>() {{
            put(CacheHandlerConstants.CAR_MANAGE_KEY, carManageCacheService.get(vin));
            put(CacheHandlerConstants.FAULT_RULE_KEY, carFaultCacheService.get(vin));
            put(CacheHandlerConstants.ELECTRONIC_FENCE_KEY, electronicFenceCacheService.get(vin));
            put(CacheHandlerConstants.WARN_RULE_KEY, carWarnCacheService.get(vin));
        }});
    }
}
