package com.muyu.event.process.consumer;

import cn.hutool.core.thread.ThreadUtil;
import com.alibaba.nacos.shaded.com.google.common.collect.Lists;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.stereotype.Component;

import java.time.Duration;
import java.util.Collection;

/**
 * @Author: zi run
 * @Date 2024/9/29 16:53
 * @Description 测试Kafka消费者
 */
@Slf4j
@RequiredArgsConstructor
public class TestKafkaConsumer implements InitializingBean {

    /**
     * kafka消费者
     */
    private final KafkaConsumer<String, String> kafkaConsumer;

    /**
     * kafka主题名称
     */
    private static final String topicName = "test-topic";


    @Override
    public void afterPropertiesSet() throws Exception {
        new Thread(() -> {
            log.info("启动线程监听Topic: {}", topicName);
            ThreadUtil.sleep(1000);
            Collection<String> topics = Lists.newArrayList(topicName);
            kafkaConsumer.subscribe(topics);
            while (true) {
                ConsumerRecords<String, String> consumerRecords = kafkaConsumer.poll(Duration.ofMillis(1000));
                consumerRecords.forEach(record -> {
                    String value = record.value();
                    log.info("从Kafka中消费的原始数据: {}", value);
                });
            }
        }).start();
    }
}