package com.muyu.event.process.controller;

import com.alibaba.fastjson2.JSONObject;
import com.muyu.common.core.constant.Constants;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.event.process.iotdb.service.TestIoTDBService;
import lombok.RequiredArgsConstructor;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * @Author: zi run
 * @Date 2024/9/29 16:24
 * @Description 测试事件控制层
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(value = "/test-event")
public class TestEventController extends BaseController {

    /**
     * kafka生产者
     */
    private final KafkaProducer<String, String> kafkaProducer;

    /**
     * kafka主题名称
     */
    private static final String kafkaTopicName = "test-topic";

    /**
     * 测试IoTDB业务层
     */
    private final TestIoTDBService testIoTDBService;

    /**
     * 发送和接收消息的Spring AMQP组件
     */
    private final RabbitTemplate rabbitTemplate;

    /**
     * rabbitMQ队列名称
     */
    private static final String rabbitMQQueueName = "test-rabbitmq";

    /**
     * 发送Kafka测试消息
     *
     * @return 响应结果
     */
    @GetMapping(value = "/sendKafka")
    public Result<String> senKafka() {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("id","1");
        jsonObject.put("name","张三");
        jsonObject.put("age","18");
        jsonObject.put("sex","男");
        ProducerRecord<String, String> producerRecord = new ProducerRecord<>(kafkaTopicName, jsonObject.toJSONString());
        kafkaProducer.send(producerRecord);
        return Result.success(null, Constants.SUCCESS_MESSAGE);
    }

    /**
     * 发送RabbitMQ测试消息
     *
     * @return 响应结果
     */
    @GetMapping(value = "/sendRabbitmq")
    public Result<String> sendRabbitMQ() {
        rabbitTemplate.convertAndSend(rabbitMQQueueName, "测试RabbitMQ队列消息", message -> {
            message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
            return message;
        });
        return Result.success(null, Constants.SUCCESS_MESSAGE);
    }

    /**
     * 查询IoTDB数据列表
     * @return 响应结果
     */
    @GetMapping(value = "/list")
    public Result<List<Map<String, Object>>> list() {
        return Result.success(testIoTDBService.list(), Constants.SUCCESS_MESSAGE);
    }

    /**
     * 向IoTDB添加数据
     *
     * @return 响应结果
     */
    @PostMapping(value = "/save")
    public Result<String> save() {
        String deviceId = "root.test";
        ArrayList<String> keyList = new ArrayList<>();
        ArrayList<String> valueList = new ArrayList<>();
        keyList.add("car_vin");
        keyList.add("car_name");
        valueList.add("VIN123456");
        valueList.add("宝马");
        testIoTDBService.insertStringRecord(deviceId, System.currentTimeMillis(), keyList, valueList);
        return Result.success(null, Constants.SUCCESS_MESSAGE);
    }
}