package com.muyu.event.process.iotdb.basic.config;

import lombok.extern.slf4j.Slf4j;
import org.apache.iotdb.session.pool.SessionPool;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.stereotype.Component;
import java.util.List;

/**
 * @Author: zi run
 * @Date 2024/9/28 22:41
 * @Description IoTDB会话配置
 */
@Slf4j
@Component
@Configuration
public class IoTDBSessionConfig {

    @Value("${spring.iotdb.username}")
    private String username;

    @Value("${spring.iotdb.password}")
    private String password;

    @Value("${spring.iotdb.ip}")
    private String ip;

    @Value("${spring.iotdb.port}")
    private int port;

    @Value("${spring.iotdb.maxSize}")
    private int maxSize;

    /**
     * IoTDB会话池
     */
    private static SessionPool sessionPool = null;

    /**
     * 获取IoTDB会话对象
     * @return ioTDB会话对象
     */
    public SessionPool getSessionPool() {
        if (sessionPool == null) {
            sessionPool = new SessionPool(ip, port, username, password, maxSize);
        }
        return sessionPool;
    }

    /**
     * 向IoTDB中插入特定设备的记录
     *
     * @param deviceId     设备的唯一标识符
     * @param time         记录的时间戳，以毫秒为单位
     * @param measurements 与记录关联的测量名称列表
     * @param values       每个测量对应的值列表。值的顺序必须与测量名称一一对应
     *
     * <p>该方法从会话池中获取一个会话，并尝试将指定的记录插入到 IoTDB 中。
     * 如果插入失败，将记录错误信息，便于后续排查。</p>
     */
    public void insertRecord(String deviceId, long time, List<String> measurements, List<String> values) {
        getSessionPool();
        try {
            log.info("iotdb数据入库：device_id:[{}], measurements:[{}], values:[{}]", deviceId, measurements, values);
            sessionPool.insertRecord(deviceId, time, measurements, values);
        } catch (Exception e) {
            log.error("IotDBSession insertRecord失败: deviceId={}, time={}, measurements={}, values={}, error={}",
                    deviceId, time, measurements, values, e.getMessage());
        }
    }
}