package com.muyu.event.process.listener;

import com.alibaba.fastjson2.JSONObject;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.enterprise.domain.FaultRule;
import com.muyu.event.process.basic.BasicEvent;
import com.muyu.event.process.basic.BasicEventListener;
import com.muyu.event.process.constant.CacheHandlerConstants;
import com.muyu.event.process.util.CacheUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.Optional;

/**
 * @Author: zi run
 * @Date 2024/10/6 14:28
 * @Description 识别故障事件监听器
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class IdentifyingFailuresEventListener implements BasicEventListener<String> {

    /**
     * 本地缓存工具
     */
    private final CacheUtil<Object> cacheUtil;

    @Override
    public void onEvent(BasicEvent<String> event) {
        log.info("触发识别故障时间监听器……");
        JSONObject data = JSONObject.parseObject(event.getData());
        Optional<Map<String, Object>> optionalDataMap =
                Optional.ofNullable((Map<String, Object>) cacheUtil.get((String) data.get("vin")));
        optionalDataMap
                .map(dataMap -> (FaultRule) dataMap.get(CacheHandlerConstants.FAULT_RULE_KEY))
                .orElseThrow(() -> new ServiceException("故障规则未找到"));
    }
}
