package com.muyu.event.process.util;

import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import org.springframework.stereotype.Component;

/**
 * @Author: zi run
 * @Date 2024/10/4 14:25
 * @Description 缓存工具
 */
@Component
public class CacheUtil<T> {

    /**
     * Caffeine缓存实例，用于存储键值对
     */
    private final Cache<String, T> cache;

    /**
     * 构造方法，初始化Caffeine缓存
     */
    public CacheUtil() {
        this.cache = Caffeine.newBuilder()
                .maximumSize(500L)
                .build();
    }

    /**
     * 根据给定的键获取缓存中的值
     *
     * @param key 要查询的缓存键
     * @return 与键对应的值，如果不存在则返回null
     */
    public T get(String key) {
        return (T) cache.getIfPresent(key);
    }

    /**
     * 将指定的键值对放入缓存中
     *
     * @param key 要存放的缓存键
     * @param value 要存放的缓存值
     */
    public void put(String key, T value) {
        cache.put(key, value);
    }

    /**
     * 根据给定的键移除缓存中的值
     *
     * @param key 要移除的缓存键
     */
    public void remove(String key) {
        cache.invalidate(key);
    }
}
