package com.muyu.system.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.InnerAuth;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.*;
import com.muyu.common.system.domain.form.RegisterBody;
import com.muyu.system.domain.resp.AuthRoleResp;
import com.muyu.system.domain.resp.UserDetailInfoResp;
import com.muyu.system.domain.resp.UserInfoResp;
import com.muyu.system.service.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ArrayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import jakarta.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.sql.*;
import java.util.Collection;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * 用户信息
 *
 * @author muyu
 */
@Slf4j
@RestController
@RequestMapping("/user")
public class SysUserController extends BaseController {
    @Autowired
    private SysUserService userService;

    @Autowired
    private SysRoleService roleService;

    @Autowired
    private SysDeptService deptService;

    @Autowired
    private SysPostService postService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private SysConfigService configService;

    @Autowired
    private SysEntService entService;
    /**
     * 获取用户列表
     */
    @RequiresPermissions("system:user:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysUser>> list (SysUser user) {
        startPage();
        List<SysUser> list = userService.selectUserList(user);
        return getDataTable(list);
    }

    @Log(title = "用户管理", businessType = BusinessType.EXPORT)
    @RequiresPermissions("system:user:export")
    @PostMapping("/export")
    public void export (HttpServletResponse response, SysUser user) {
        List<SysUser> list = userService.selectUserList(user);
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        util.exportExcel(response, list, "用户数据");
    }

    @Log(title = "用户管理", businessType = BusinessType.IMPORT)
    @RequiresPermissions("system:user:import")
    @PostMapping("/importData")
    public Result importData (MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        List<SysUser> userList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = userService.importUser(userList, updateSupport, operName);
        return success(message);
    }

    @PostMapping("/importTemplate")
    public void importTemplate (HttpServletResponse response) throws IOException {
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        util.importTemplateExcel(response, "用户数据");
    }

    /**
     * 获取当前用户信息
     */
    @InnerAuth
    @GetMapping("/info/{username}")
    public Result<LoginUser> info (@PathVariable("username") String username) {
        SysUser sysUser = userService.selectUserByUserName(username);
        if (StringUtils.isNull(sysUser)) {
            return Result.error("用户名或密码错误");
        }
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(sysUser);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(sysUser);
        LoginUser sysUserVo = new LoginUser();
        sysUserVo.setSysUser(sysUser);
        sysUserVo.setRoles(roles);
        sysUserVo.setPermissions(permissions);
        return Result.success(sysUserVo);
    }

    /**
     * 注册用户信息
     */
    @InnerAuth
    @PostMapping("/register")
    public Result<Boolean> register (@RequestBody RegisterBody registerBody) {
        String username = registerBody.getUsername();
        SysUser sysUser = new SysUser();
        sysUser.setUserName(username);
        if (!userService.checkUserNameUnique(sysUser)) {
            return Result.error("保存用户'" + username + "'失败，注册账号已存在");
        }
        if (!("true".equals(configService.selectConfigByKey("sys.account.registerUser")))) {
            return Result.error("当前系统没有开启注册功能！");
        }
        if (!userService.checkUserNameUnique(sysUser)) {
            return Result.error("保存用户'" + username + "'失败，注册账号已存在");
        }
        //添加企业
        SysEnt sysEnt = SysEnt.builder()
                .name(registerBody.getEntName())
                .leader(registerBody.getLeader())
                .phone(registerBody.getPhone())
                .email(registerBody.getEmail())
                .entCode(registerBody.getUsername())
                .build();
        entService.save(sysEnt);

        //添加部门
        SysDept sysDept = SysDept.builder()
                .deptName(registerBody.getEntName())
                .leader(registerBody.getLeader())
                .phone(registerBody.getPhone())
                .email(registerBody.getEmail())
                .entId(sysEnt.getId())
                .parentId(100L)
                .build();
        deptService.insertDept(sysDept);

        sysUser.setDeptId(sysDept.getDeptId());
        sysUser.setNickName(registerBody.getUsername());
        sysUser.setPassword(SecurityUtils.encryptPassword(registerBody.getPassword()));
        sysUser.setNickName("注册");
        boolean b = userService.registerUser(sysUser);
        if (b == true) {
            //数据库驱动
            String mysqlDriver = "com.mysql.jdbc.Driver";
            //数据库地址
            String url = "jdbc:mysql://106.15.136.7:3306/";
            //数据库用户名
            String name = "root";
            //数据库密码
            String password = "Six@211206";
            Collection collection = null;
            Collection stmt = null;
            //创建数据库SQL
            try {
                Class.forName(mysqlDriver);
            } catch (ClassNotFoundException e) {
                throw new RuntimeException(e);
            }
            String databaseSQL = "create database "+username ;

            //添加企业信息
            String tableSQL = "create table sys_ent (id int auto_increment primary key comment '主键id'," +
                    "name varchar(16) comment '企业名称'," +
                    "leader varchar(16) comment '负责人'," +
                    "phone varchar(11) comment '联系电话'," +
                    "email varchar(32) comment '邮箱'," +
                    "ent_code varchar(64) comment '企业编码'," +
                    "ent_status varchar(64) comment '企业状态'," +
                    "create_by varchar(32) comment '创建人'," +
                    "update_by varchar(32) comment '创建时间'," +
                    "create_time datetime comment '修改人'," +
                    "update_time datetime comment '修改时间'," +
                    "remark varchar(32) comment '备注')";
            //连接数据库
            try {
                Connection connection = DriverManager.getConnection(url, name, password);
                //用于执行编译sql语句的对象
                Statement connStatement = connection.createStatement();
                if (connection != null) {
                    //执行建库语句
                    connStatement.executeUpdate(databaseSQL);
                    log.info("创建数据库成功");
                    //连接新建数据库
                    Connection connection1 = DriverManager.getConnection(url + username, name, password);
                    if (connection1 != null) {
                        log.info("连接数据库成功"+username);
                        Statement statement = connection1.createStatement();
                        //执行建表语句
                        statement.executeUpdate(tableSQL);
                        log.info("创建表成功");
                        String insertSQL="INSERT INTO sys_ent (name, leader, phone, email, ent_code, ent_status, create_by, create_time) VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
                        try(PreparedStatement preparedStatement = connection1.prepareStatement(insertSQL)) {
                            //设置插入的值
                            preparedStatement.setString(1,registerBody.getEntName());
                            preparedStatement.setString(2,registerBody.getLeader());
                            preparedStatement.setString(3,registerBody.getPhone());
                            preparedStatement.setString(4,registerBody.getEmail());
                            preparedStatement.setString(5,username);
                            preparedStatement.setInt(6,0);
                            preparedStatement.setString(7, sysUser.getCreateBy());
                            preparedStatement.setTimestamp(8, new Timestamp(System.currentTimeMillis())); // 当前时间
                            preparedStatement.executeUpdate();
                            log.info("插入企业信息成功");
                        }
                        return Result.success();
                    }
                }
            } catch (SQLException e) {
                throw new RuntimeException(e);
            }
        }
        return Result.success(userService.registerUser(sysUser));
    }

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public Result getInfo () {
        SysUser user = userService.selectUserById(SecurityUtils.getUserId());
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);

        return Result.success(
                UserInfoResp.builder()
                        .user(user)
                        .roles(roles)
                        .permissions(permissions)
                        .build()
        );
    }

    /**
     * 根据用户编号获取详细信息
     */
    @RequiresPermissions("system:user:query")
    @GetMapping(value = {"/", "/{userId}"})
    public Result getInfo (@PathVariable(value = "userId", required = false) Long userId) {
        userService.checkUserDataScope(userId);
        UserDetailInfoResp.UserDetailInfoRespBuilder<?, ?> builder = UserDetailInfoResp.builder();
        List<SysRole> roles = roleService.selectRoleAll();
        builder.roles(
                SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList())
        )
        .posts( postService.selectPostAll() );
        if (StringUtils.isNotNull(userId)) {
            SysUser sysUser = userService.selectUserById(userId);
            builder.sysUser(sysUser)
                    .postIds(postService.selectPostListByUserId(userId))
                    .roleIds(sysUser.getRoles().stream().map(SysRole::getRoleId).collect(Collectors.toList()))
                    .build();
        }
        return Result.success(builder.build());
    }

    /**
     * 新增用户
     */
    @RequiresPermissions("system:user:add")
    @Log(title = "用户管理", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add (@Validated @RequestBody SysUser user) {
        if (!userService.checkUserNameUnique(user)) {
            return error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        } else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !userService.checkPhoneUnique(user)) {
            return error("新增用户'" + user.getUserName() + "'失败，手机号码已存在");
        } else if (StringUtils.isNotEmpty(user.getEmail()) && !userService.checkEmailUnique(user)) {
            return error("新增用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setCreateBy(SecurityUtils.getUsername());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        return toAjax(userService.insertUser(user));
    }

    /**
     * 修改用户
     */
    @RequiresPermissions("system:user:edit")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit (@Validated @RequestBody SysUser user) {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        if (!userService.checkUserNameUnique(user)) {
            return error("修改用户'" + user.getUserName() + "'失败，登录账号已存在");
        } else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !userService.checkPhoneUnique(user)) {
            return error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
        } else if (StringUtils.isNotEmpty(user.getEmail()) && !userService.checkEmailUnique(user)) {
            return error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        user.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(userService.updateUser(user));
    }

    /**
     * 删除用户
     */
    @RequiresPermissions("system:user:remove")
    @Log(title = "用户管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{userIds}")
    public Result remove (@PathVariable("userIds") Long[] userIds) {
        if (ArrayUtils.contains(userIds, SecurityUtils.getUserId())) {
            return error("当前用户不能删除");
        }
        return toAjax(userService.deleteUserByIds(userIds));
    }

    /**
     * 重置密码
     */
    @RequiresPermissions("system:user:edit")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping("/resetPwd")
    public Result resetPwd (@RequestBody SysUser user) {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        user.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(userService.resetPwd(user));
    }

    /**
     * 状态修改
     */
    @RequiresPermissions("system:user:edit")
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public Result changeStatus (@RequestBody SysUser user) {
        userService.checkUserAllowed(user);
        userService.checkUserDataScope(user.getUserId());
        user.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(userService.updateUserStatus(user));
    }

    /**
     * 根据用户编号获取授权角色
     */
    @RequiresPermissions("system:user:query")
    @GetMapping("/authRole/{userId}")
    public Result authRole (@PathVariable("userId") Long userId) {
        SysUser user = userService.selectUserById(userId);
        List<SysRole> roles = roleService.selectRolesByUserId(userId);
        return Result.success(
                AuthRoleResp.builder()
                        .roles(SysUser.isAdmin(userId) ? roles : roles.stream().filter(r -> !r.isAdmin()).collect(Collectors.toList()))
                        .user(user)
                        .build()
        );
    }

    /**
     * 用户授权角色
     */
    @RequiresPermissions("system:user:edit")
    @Log(title = "用户管理", businessType = BusinessType.GRANT)
    @PutMapping("/authRole")
    public Result insertAuthRole (Long userId, Long[] roleIds) {
        userService.checkUserDataScope(userId);
        userService.insertUserAuth(userId, roleIds);
        return success();
    }

    /**
     * 获取部门树列表
     */
    @RequiresPermissions("system:user:list")
    @GetMapping("/deptTree")
    public Result deptTree (SysDept dept) {
        return success(deptService.selectDeptTreeList(dept));
    }

    /**
     * 获取企业信息
     * @return 用户信息
     */
    @GetMapping("/entList")
    public Result<List<SysUser>> entList() {
        return success(userService.entList());
    }
}
