package com.muyu.vehiclegateway.controller;

import io.swagger.v3.oas.annotations.tags.Tag;
import org.eclipse.paho.client.mqttv3.*;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @ClassName VehicleGatewayController
 * @Description 描述
 * @Author YiBo.Liu
 * @Date 2024/9/27 20:02
 */
@RequestMapping("/vehicleGateway")
@RestController
@Tag(name = "车辆网关",description = "车辆网关管理负载中心")
public class VehicleGatewayController {


    /**
     * 用于链接MQtt获取车联信息
     */
    @PostMapping("/MqttPublishSample")
    public static void MqttPublishSample(){
        //定义MQTT主题
        String topic = "vehicle";
        //定义要发布的消息内容
        String content = "Message from MqttPublishSample";
        //定义消息服务质量(qos)等级
        int qos = 2;
        //定义MQTT代理服务器地址
        String broker = "tcp://106.15.136.7:1883";
        //定义客户端标识符
        String clientId = "JavaSample";
        //创建MemoryPersistence对象,用于消息的内存持久性
        MemoryPersistence persistence = new MemoryPersistence();

        try{
            //创建MqttClient实例,连接到MQTT代理服务器
            MqttClient sampleClient = new MqttClient(broker,clientId);

            //创建MqttConnectOptions对象,用于配置连接选项
            MqttConnectOptions connOpts = new MqttConnectOptions();
            //设置CleanSession为true,标识每个连接都是一个全新的会话
            connOpts.setCleanSession(true);
            //打印连接信息
            System.out.println("Connecting to broker: " + broker);

            sampleClient.connect(connOpts);
            sampleClient.subscribe(topic,0);
            sampleClient.setCallback(new MqttCallback() {

                //连接报错
                @Override
                public void connectionLost(Throwable throwable) {

                }
                //接收到消息
                @Override
                public void messageArrived(String s, MqttMessage mqttMessage) throws Exception {
                    System.out.println(new String(mqttMessage.getPayload()));
                }
                //消费完成
                @Override
                public void deliveryComplete(IMqttDeliveryToken iMqttDeliveryToken) {

                }
            });
        } catch(MqttException me) {
            System.out.println("reason "+me.getReasonCode());
            System.out.println("msg "+me.getMessage());
            System.out.println("loc "+me.getLocalizedMessage());
            System.out.println("cause "+me.getCause());
            System.out.println("excep "+me);
            me.printStackTrace();

        }

    }


}
