package com.muyu.vehiclegateway.instance;

import com.aliyun.ecs20140526.Client;
import com.aliyun.ecs20140526.models.DescribeInstancesRequest;
import com.aliyun.ecs20140526.models.DescribeInstancesResponse;
import com.aliyun.ecs20140526.models.DescribeInstancesResponseBody;
import com.aliyun.ecs20140526.models.RunInstancesRequest;
import com.aliyun.tea.TeaException;
import com.aliyun.teautil.Common;
import com.aliyun.teautil.models.RuntimeOptions;
import com.muyu.common.redis.service.RedisService;
import com.muyu.vehiclegateway.domain.Instance;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName GenerateInstance
 * @Description 程序启动创建ECS服务器实例
 * @Author YiBo.Liu
 * @Date 2024/9/28 19:39
 */
@Component
@Log4j2
@Tag(name = "程序启动创建ECS服务器实例")
public class GenerateInstance implements ApplicationRunner {


    @Autowired
    private  RedisService redisService;

    /**
     * 启动自动创建实例
     * @throws Exception
     */
    public List<Instance> generateInstance() throws Exception {

        // 创建ECS客户端对象，用于后续调用ECS相关API
        Client client = CreateClient.createClient();

        RunInstancesRequest.RunInstancesRequestSystemDisk systemDisk = new RunInstancesRequest.RunInstancesRequestSystemDisk()
                .setSize("40")
                .setCategory("cloud_essd");
        RunInstancesRequest runInstancesRequest = new RunInstancesRequest()
                // 设置地域ID
                .setRegionId("cn-shanghai")
                // 设置镜像ID
                .setImageId("m-uf6f7atj16s3cjn9q5l8")
                // 设置实例类型
                .setInstanceType("ecs.t6-c1m1.large")
                // 设置安全组ID
                .setSecurityGroupId("sg-uf6f6dvazjqv127a4yyt")
                // 设置虚拟交换机ID
                .setVSwitchId("vsw-uf6htez4ox9k2c4cs8505")
                // 设置实例名称
                .setInstanceName("server-mqtt")
                // 设置实例付费类型为后付费按量付费
                .setInstanceChargeType("PostPaid")
                // 设置互联网最大出带宽为1 Mbps
                .setInternetMaxBandwidthOut(1)
                // 设置系统盘配置
                .setSystemDisk(systemDisk)
                // 设置主机名
                .setHostName("root")
                // 设置实例密码
                .setPassword("Six@211206")
                // 设置创建实例的数量
                .setAmount(1);

        RuntimeOptions runtime = new RuntimeOptions();
        try {
            // 复制代码运行请自行打印 API 的返回值
            client.runInstancesWithOptions(runInstancesRequest, runtime);
        } catch (TeaException error) {
            // 此处仅做打印展示，请谨慎对待异常处理，在工程项目中切勿直接忽略异常。
            // 错误 message
            System.out.println(error.getMessage());
            // 诊断地址
            System.out.println(error.getData().get("Recommend"));
            Common.assertAsString(error.message);
        } catch (Exception _error) {
            TeaException error = new TeaException(_error.getMessage(), _error);
            // 此处仅做打印展示，请谨慎对待异常处理，在工程项目中切勿直接忽略异常。
            // 错误 message
            System.out.println(error.getMessage());
            // 诊断地址
            System.out.println(error.getData().get("Recommend"));
            Common.assertAsString(error.message);
        }

        DescribeInstancesRequest describeInstancesRequest = new DescribeInstancesRequest()
                .setRegionId("cn-shanghai");

        //创建运行时选择对象,用于配置运行时的选项参数
        RuntimeOptions runtimeOptions = new RuntimeOptions();

        //获取实例列表
        DescribeInstancesResponse describeInstancesResponse = client.describeInstancesWithOptions(describeInstancesRequest, runtimeOptions);

        //提取实例ID集合
        List<Instance> list = new ArrayList<>();

        DescribeInstancesResponseBody body = describeInstancesResponse.getBody();

        for (DescribeInstancesResponseBody.DescribeInstancesResponseBodyInstancesInstance instance : body.getInstances().getInstance()) {

            log.info("实例id为:"+instance.getInstanceId());
            log.info("实例ip为:"+instance.getPublicIpAddress().ipAddress.get(0));
            log.info("实例状态为:"+instance.getStatus());

            Instance instance1 = new Instance(instance.getInstanceId(), instance.getPublicIpAddress().ipAddress.get(0), instance.getStatus());

            list.add(instance1);
        }

//        Thread.sleep(20000);
//        redisService.setCacheList("aaa",list);

        return list;

    }


    @Override
    public void run(ApplicationArguments args) throws Exception {
        generateInstance();
        System.out.println("创建实例成功");
    }



}
